@@ -1,25 +1,26 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from __future__ import print_function, unicode_literals
-from ..lib.handler.captainhook_handler import CaptainHook
-from ..lib.logger import Logger
 import sys
 
+from suite_py.lib.handler.captainhook_handler import CaptainHook
+from suite_py.lib.logger import Logger
+
 logger = Logger()
-lock = CaptainHook()
 
 
-def entrypoint(args):
-    if(args.action in ['lock', 'l']):
-        req = lock.lock_project(args.project)
+def entrypoint(project, action, timeout):
+    lock = CaptainHook()
+    if timeout:
+        lock.set_timeout(timeout)
+    if(action in ['lock', 'l']):
+        req = lock.lock_project(project)
         handle_request(req)
         logger.info(
-            'Bloccato deploy su staging del progetto {}'.format(args.project))
-    elif(args.action in ['unlock', 'u']):
-        req = lock.unlock_project(args.project)
+            'Bloccato deploy su staging del progetto {}'.format(project))
+    elif(action in ['unlock', 'u']):
+        req = lock.unlock_project(project)
         handle_request(req)
         logger.info(
-            'Abilitato deploy su staging del progetto {}'.format(args.project))
+            'Abilitato deploy su staging del progetto {}'.format(project))
     else:
         logger.warning('Non ho capito che cosa devo fare')
         sys.exit(-1)
