@@ -1,31 +1,37 @@
-from __future__ import print_function, unicode_literals
-from ..lib.handler.youtrack_handler import YoutrackHandler
-from ..lib.handler.github_handler import GithubHandler
-from ..lib.handler.captainhook_handler import CaptainHook
-from ..lib.config import Config
-from ..lib.logger import Logger
-from ..lib.handler import prompt_utils
-from ..lib.qainit import qainit_shutdown
-from ..lib.handler import git_handler as git
-from ..lib.handler import drone_handler as drone
+# -*- coding: utf-8 -*-
 import os
-import sys
 import re
+import sys
+
+from suite_py.lib.handler.youtrack_handler import YoutrackHandler
+from suite_py.lib.handler.github_handler import GithubHandler
+from suite_py.lib.handler.captainhook_handler import CaptainHook
+from suite_py.lib.config import Config
+from suite_py.lib.logger import Logger
+from suite_py.lib.handler import prompt_utils
+from suite_py.lib.qainit import qainit_shutdown
+from suite_py.lib.handler import git_handler as git
+from suite_py.lib.handler import drone_handler as drone
+
 
 youtrack = YoutrackHandler()
 github = GithubHandler()
 logger = Logger()
-lock = CaptainHook()
 config = Config().load()
 
 
-def entrypoint(args):
-    stop_if_master_locked(args.project)
+def entrypoint(project, timeout):
+    lock = CaptainHook()
+    if timeout:
+        lock.set_timeout(timeout)
 
-    pr = select_pr(args.project)
+    stop_if_master_locked(project, lock)
+
+    pr = select_pr(project)
     branch_name = pr.head.ref
     youtrack_id = youtrack.get_card_from_name(branch_name)
 
+
     check_migrations_merge(pr)
 
     logger.info("Eseguo il merge...")
@@ -37,7 +43,7 @@ def entrypoint(args):
         logger.error("Si è verificato un errore durante il merge.")
         sys.exit(-1)
 
-    drone_build = get_drone_build(args.project, merge_status.sha)
+    drone_build = get_drone_build(project, merge_status.sha)
 
     if drone_build:
         logger.info(
@@ -45,12 +51,12 @@ def entrypoint(args):
     else:
         logger.info("Pull request mergiata su master!")
 
-    git.fetch(args.project)
-    if git.remote_branch_exists(args.project, branch_name):
-        git.delete_remote_branch(args.project, branch_name)
+    git.fetch(project)
+    if git.remote_branch_exists(project, branch_name):
+        git.delete_remote_branch(project, branch_name)
 
-    if prompt_utils.ask_confirm("Vuoi bloccare staging? (Necessario se bisogna testare su staging)".format(args.project), default=False):
-        lock.lock_project(args.project)
+    if prompt_utils.ask_confirm("Vuoi bloccare staging? (Necessario se bisogna testare su staging)", default=False):
+        lock.lock_project(project)
 
     if youtrack_id:
         logger.info("Aggiorno lo stato della card su youtrack...")
@@ -90,8 +96,13 @@ def select_pr(project):
         sys.exit(-1)
 
 
-def stop_if_master_locked(project):
-    request = lock.status(project)
+def stop_if_master_locked(project, lock):
+    try:
+        request = lock.status(project)
+    except:
+        logger.error("Impossibile contattare CaptainHook, stai usando la VPN?")
+        sys.exit(-1)
+
     if request.status_code != 200:
         logger.error("Impossibile determinare lo stato del lock su master.")
         sys.exit(-1)
