@@ -1,25 +1,28 @@
-from __future__ import print_function, unicode_literals
-from ..lib.handler.github_handler import GithubHandler
-from ..lib.handler.slack_handler import SlackHandler
-from ..lib.handler import prompt_utils
-from ..lib.handler import aws_handler as aws
-from ..lib.handler import drone_handler as drone
-from ..lib.logger import Logger
+# -*- encoding: utf-8 -*-
 from distutils.version import StrictVersion
-from halo import Halo
-import sys
 import re
+import sys
+
+from halo import Halo
+
+from suite_py.lib.handler.github_handler import GithubHandler
+from suite_py.lib.handler.slack_handler import SlackHandler
+from suite_py.lib.handler import prompt_utils
+from suite_py.lib.handler import aws_handler as aws
+from suite_py.lib.handler import drone_handler as drone
+from suite_py.lib.logger import Logger
+
 
 github = GithubHandler()
 logger = Logger()
 slack = SlackHandler()
 
 
-def entrypoint(args):
+def entrypoint(project):
     bucket_name = "prima-artifacts-encrypted"
-    repo = github.get_repo(args.project)
+    repo = github.get_repo(project)
 
-    if args.project == "prima":
+    if project == "prima":
         stacks_name = ["ecs-task-web-vpc-production", "ecs-task-consumer-vpc-production",
                        "ecs-task-cron-vpc-production", "batch-job-php-production"]
         prefix = "prima/"
@@ -27,30 +30,30 @@ def entrypoint(args):
         artifacts = aws.get_artifacts_from_s3(
             bucket_name, prefix)
         versions, prima_version_mapping = get_versions_from_artifacts(
-            args.project, bucket_name, artifacts)
+            project, bucket_name, artifacts)
 
         version = ask_version(repo, versions)
         rollback_stacks(args.project, stacks_name,
                         prima_version_mapping[version])
 
-    elif aws.is_cloudfront_distribution(args.project):
+    elif aws.is_cloudfront_distribution(project):
         with Halo(text='Loading releases...', spinner='dots', color='magenta'):
-            versions = drone.get_tag_from_builds(args.project)
+            versions = drone.get_tag_from_builds(project)
         version = ask_version(repo, versions)
-        build = drone.get_build_from_tag(args.project, version)
-        drone.launch_build(args.project, build)
+        build = drone.get_build_from_tag(project, version)
+        drone.launch_build(project, build)
         logger.info("Build rilanciata, controlla lo stato su drone")
         post_rollback_complete_on_slack(args.project, version)
 
     else:
-        stacks_name = aws.get_stacks_name(args.project)
-        prefix = "microservices/{}/".format(args.project)
+        stacks_name = aws.get_stacks_name(project)
+        prefix = "microservices/{}/".format(project)
 
         if len(stacks_name) > 0:
             artifacts = aws.get_artifacts_from_s3(
                 bucket_name, prefix)
             versions, _ = get_versions_from_artifacts(
-                args.project, bucket_name, artifacts)
+                project, bucket_name, artifacts)
 
             if len(versions) > 0:
                 version = ask_version(repo, versions)
