@@ -1,10 +1,12 @@
-from __future__ import print_function, unicode_literals
-from ..logger import Logger
-from halo import Halo
+# -*- encoding: utf-8 -*-
 import sys
-import boto3
 import time
 
+import boto3
+from halo import Halo
+
+from suite_py.lib.logger import Logger
+
 logger = Logger()
 
 cloudformation = boto3.client('cloudformation')
