@@ -1,11 +1,13 @@
-from __future__ import print_function, unicode_literals
-from ..tokens import Tokens
-from ..config import Config
-from ..singleton import Singleton
+# -*- encoding: utf-8 -*-
+import os
+
 from PyInquirer import prompt
 import slack
 
-import os
+from suite_py.lib.tokens import Tokens
+from suite_py.lib.config import Config
+from suite_py.lib.singleton import Singleton
+
 
 tokens = Tokens()
 
