@@ -1,6 +1,7 @@
-from __future__ import print_function, unicode_literals
+# -*- encoding: utf-8 -*-
 from termcolor import colored
-from .singleton import Singleton
+
+from suite_py.lib.singleton import Singleton
 
 
 class Logger(metaclass=Singleton):
